==> jc-1.4.0.tar.gz: javax/swing/text/DefaultEditorKit__245.h <==
// final class javax.swing.text.DefaultEditorKit$5

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 98474664576ab478 javax_swing_text_DefaultEditorKit__245
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__245_H_
#define _JC_javax_swing_text_DefaultEditorKit__245_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$sub_refs	_jc_javax_swing_text_DefaultEditorKit__245$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$refs	_jc_javax_swing_text_DefaultEditorKit__245$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$nonrefs	_jc_javax_swing_text_DefaultEditorKit__245$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$object	_jc_javax_swing_text_DefaultEditorKit__245$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__245$vmethods	_jc_javax_swing_text_DefaultEditorKit__245$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__245$vtable	_jc_javax_swing_text_DefaultEditorKit__245$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__245$vtype	_jc_javax_swing_text_DefaultEditorKit__245$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__245$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__245$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__245$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__245$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__245$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__245$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__245$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__245$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__245$vmethods	javax_swing_text_DefaultEditorKit__245;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__245$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__245$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__245$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__245$refs {
    _jc_javax_swing_text_DefaultEditorKit__245$sub_refs	javax_swing_text_DefaultEditorKit__245;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__245$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs	javax_swing_text_DefaultEditorKit__245;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__245$object {
	_jc_javax_swing_text_DefaultEditorKit__245$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__245$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__245$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__245$vtype _jc_javax_swing_text_DefaultEditorKit__245$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__245, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__245$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__245_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/DefaultEditorKit__245.h <==
// final class javax.swing.text.DefaultEditorKit$5

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class 1b59d304a8c8dc80 javax_swing_text_DefaultEditorKit__245
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_text_TextAction

#include "javax/swing/text/TextAction.h"

#ifndef _JC_javax_swing_text_DefaultEditorKit__245_H_
#define _JC_javax_swing_text_DefaultEditorKit__245_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$sub_refs	_jc_javax_swing_text_DefaultEditorKit__245$sub_refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs	_jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$refs	_jc_javax_swing_text_DefaultEditorKit__245$refs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$nonrefs	_jc_javax_swing_text_DefaultEditorKit__245$nonrefs;
typedef struct _jc_javax_swing_text_DefaultEditorKit__245$object	_jc_javax_swing_text_DefaultEditorKit__245$object;

typedef const struct _jc_javax_swing_text_DefaultEditorKit__245$vmethods	_jc_javax_swing_text_DefaultEditorKit__245$vmethods;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__245$vtable	_jc_javax_swing_text_DefaultEditorKit__245$vtable;
typedef const struct _jc_javax_swing_text_DefaultEditorKit__245$vtype	_jc_javax_swing_text_DefaultEditorKit__245$vtype;

// Constructors
extern void _jc_javax_swing_text_DefaultEditorKit__245$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__245$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_DefaultEditorKit__245$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__245$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_DefaultEditorKit__245$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_text_DefaultEditorKit__245$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_text_DefaultEditorKit__245$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_DefaultEditorKit__245$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
	_jc_javax_swing_text_DefaultEditorKit__245$vmethods	javax_swing_text_DefaultEditorKit__245;
};

// Vtype
struct _jc_javax_swing_text_DefaultEditorKit__245$vtype {
	_jc_type			type;
	_jc_javax_swing_text_DefaultEditorKit__245$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__245$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__245$refs {
    _jc_javax_swing_text_DefaultEditorKit__245$sub_refs	javax_swing_text_DefaultEditorKit__245;
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_DefaultEditorKit__245$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
    _jc_javax_swing_text_DefaultEditorKit__245$sub_nonrefs	javax_swing_text_DefaultEditorKit__245;
};

// Object instance structure
struct _jc_javax_swing_text_DefaultEditorKit__245$object {
	_jc_javax_swing_text_DefaultEditorKit__245$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_DefaultEditorKit__245$vtype	*vtype;
	_jc_javax_swing_text_DefaultEditorKit__245$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_DefaultEditorKit__245$vtype _jc_javax_swing_text_DefaultEditorKit__245$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_DefaultEditorKit__245, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_DefaultEditorKit__245$class_object;

#endif	/* _JC_javax_swing_text_DefaultEditorKit__245_H_ */
